@@ -14,12 +14,14 @@
    You should have received a copy of the GNU General Public License
    along with Redshift.  If not, see <http://www.gnu.org/licenses/>.
 
-   Copyright (c) 2010  Jon Lund Steffensen <jonlst@gmail.com>
+   Copyright (c) 2010-2014  Jon Lund Steffensen <jonlst@gmail.com>
 */
 
 #ifndef REDSHIFT_GAMMA_VIDMODE_H
 #define REDSHIFT_GAMMA_VIDMODE_H
 
+#include "redshift.h"
+
 #include <stdio.h>
 #include <stdint.h>
 
@@ -42,8 +44,8 @@ int vidmode_set_option(vidmode_state_t *state, const char *key,
 		       const char *value);
 
 void vidmode_restore(vidmode_state_t *state);
-int vidmode_set_temperature(vidmode_state_t *state, int temp, float brightness,
-			    const float gamma[3]);
+int vidmode_set_temperature(vidmode_state_t *state,
+			    const color_setting_t *setting);
 
 
 #endif /* ! REDSHIFT_GAMMA_VIDMODE_H */
